/*******************************************************************

   This software is the confidential  and proprietary information of
   NetCat AG.   You shall not disclose such confidential information
   and shall use it only in accordance with the terms of the license
   agreement you entered into with NetCat AG.

   Copyright (c) 2003 by NetCat AG, www.netcat.li

   Author: Arthur Marxer, Dipl. Informatik-Ing. ETH

*******************************************************************/

import java.awt.*;
import java.awt.event.*;
import java.io.*;
import java.net.*;
import java.text.*;
import java.util.*;
import java.util.List;
import javax.swing.*;
import javax.swing.table.*;


import li.netcat.smartsync.*;

public class ProgressPanel extends DataPanel {
  private static DecimalFormat _kBitFormat = new DecimalFormat("#,###,###,##0.00 kBit/s");
  private static DecimalFormat _mBitFormat = new DecimalFormat("#,###,###,##0.00 MBit/s");
  private static DecimalFormat _nrOfFilesFormat = new DecimalFormat("#,###,###,##0 Files");
  private static final String  _oneFileString = "1 File";
  private static DecimalFormat _trafficFormat = new DecimalFormat("#,###,###,##0 Byte");
  private JLabel       _transferRate;
  private JLabel       _completedFiles;
  private JLabel       _completedTraffic;
  private JLabel       _remainTime;
  private JLabel       _remainFiles;
  private JLabel       _remainTraffic;
  private JProgressBar _progressBar;
  
  public ProgressPanel() {
    super(new BorderLayout(10, 10));
    setBackground(Color.white);
    JPanel recordPanel1 = createRecordPanel(new JLabel[]{new JLabel("Transfer rate:"), new JLabel("Transferred files:"), new JLabel("Transferred traffic:")},
                                            new JLabel[]{_transferRate=new JLabel(), _completedFiles=new JLabel(), _completedTraffic = new JLabel()});
    JPanel recordPanel2 = createRecordPanel(new JLabel[]{new JLabel("Remaining time:"), new JLabel("Remaining files:"), new JLabel("Remaining traffic:")},
                                            new JLabel[]{_remainTime=new JLabel(), _remainFiles=new JLabel(),  _remainTraffic=new JLabel()});
    JPanel recordPanel = createJPanel(new GridLayout(1, 2));
    recordPanel.add(recordPanel1);
    recordPanel.add(recordPanel2);
    add(recordPanel, BorderLayout.CENTER);
    _progressBar = new JProgressBar(SwingConstants.HORIZONTAL, 0, 100);
    _progressBar.setStringPainted(true);
    add(_progressBar, BorderLayout.SOUTH);
    setInsets(0, 0, 5, 0);
  }
  
  public void setTransferProgress(TransferProgress progress) {
    _transferRate.setText(formatTransferRate(progress.getTransferRate()));
    _completedFiles.setText(formatNrOfFiles(progress.getCompletedFiles()));
    _completedTraffic.setText(formatTraffic(progress.getCompletedTraffic()));
    _remainTime.setText(formatRemainingTime(progress.getRemainingTime()));
    _remainFiles.setText(formatNrOfFiles(progress.getRemainingFiles()));
    _remainTraffic.setText(formatTraffic(progress.getRemainingTraffic()));
    int progressValue = (int)(progress.getProgress() * 100);
    _progressBar.setValue(progressValue);
  }

  private final String formatNrOfFiles(int nrOfFiles) {
    if (nrOfFiles < 0) {
      return null;
    }
    if (nrOfFiles == 1) {
      return _oneFileString;
    }
    return _nrOfFilesFormat.format(nrOfFiles);
  }
  
  private final String formatTraffic(long traffic) {
    if (traffic < 0) {
      return null;
    }
    return _trafficFormat.format(traffic);
  }
  
  private final String formatTransferRate(long rate) {
    if (rate < 0) {
      return null;
    }
    double krate = rate/1000.0;
    return krate < 1000.0 ? _kBitFormat.format(krate) : _mBitFormat.format(krate/1000.0);
  }
  
  private final String formatRemainingTime(int time) {
    if (time < 0) {
      return null;
    }
    int sec = time % 60;
    time /= 60;
    int min = time % 60;
    int hour = time / 60;
    StringBuffer sb = new StringBuffer();
    format(hour, sb);
    sb.append(":");
    format(min, sb);
    sb.append(":");
    format(sec, sb);
    return sb.toString();
  }
  
  private void format(int i, StringBuffer sb) {
    if (i < 10) {
      sb.append("0");
    }
    sb.append(Integer.toString(i));
  }

  
}
