/*******************************************************************

   This software is the confidential  and proprietary information of
   NetCat AG.   You shall not disclose such confidential information
   and shall use it only in accordance with the terms of the license
   agreement you entered into with NetCat AG.

   Copyright (c) 2003 by NetCat AG, www.netcat.li

   Author: Arthur Marxer, Dipl. Informatik-Ing. ETH

*******************************************************************/

import java.awt.*;
import java.awt.event.*;
import java.io.*;
import java.net.*;
import java.util.*;
import java.util.List;
import javax.swing.*;
import javax.swing.table.*;


import li.netcat.smartsync.*;

public class SmartSyncMonitor extends DialogPanel implements EventMonitor {
  private JFrame     _frame;
  private InfoPanel  _infoPanel;
  private TaskPanel  _taskPanel;
  private JButton    _cancelButton;
  private JButton    _exitButton;
  private boolean    _abort = false;
  
  public SmartSyncMonitor() {
    _infoPanel = new InfoPanel();
    _taskPanel = new TaskPanel();

    JPanel content = new JPanel(new BorderLayout(5, 5));
    content.add(_infoPanel, BorderLayout.NORTH);
    content.add(_taskPanel, BorderLayout.CENTER);
    setContent(content);
    addButton(_cancelButton = new JButton("Cancel"));
    _cancelButton.setEnabled(false);
    _cancelButton.addActionListener(new CancelListener());
    addButton(_exitButton = new JButton("Exit"));
    _exitButton.addActionListener(new ExitListener());
  }
  
  public JFrame open() {
    _frame = new JFrame("SmartSync Monitor");
    _frame.setContentPane(this);
    _frame.pack();
    Rectangle bounds = _frame.getGraphicsConfiguration().getBounds();
    _frame.setLocation(bounds.x + (bounds.width -  _frame.getWidth())/2, bounds.y + (bounds.height -  _frame.getHeight())/3);
    _frame.setVisible(true);
    _frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE); // due to bug 4030718 (http://developer.java.sun.com/developer/bugParade/bugs/4030718.html)
    _frame.toFront();
    return _frame;
  }
  
  //// interface EventMonitor
  
  public void onStart(URL remoteDirectory, File localDirectory) {
    _infoPanel.setTexts(remoteDirectory.toString(), localDirectory.toString());
    _taskPanel.setText("Checking for updates...");
    open();
  }
  
  public void onTaskAnnounce(Task task) {
    _taskPanel.addTask(task);
  }

  public void onTaskStart(Task task) {
    _cancelButton.setEnabled(true);
    _taskPanel.setCurrentTask(task);
  }
  
  public void onProgress(TransferProgress progress) {
    _taskPanel.setTransferProgress(progress);
  }
  
  public void onTaskCompletion(Task task) {
    _taskPanel.setTaskCompleted(task);
  }
  
  public void onSuccess(boolean updateDone) {
    _cancelButton.setEnabled(false);
    if (updateDone) {
      JOptionPane.showMessageDialog(this, "The directory structure has been updated successfully", "Information", JOptionPane.INFORMATION_MESSAGE);
    }
    else {
      _taskPanel.setText("No update available.");
    }
  }
  
  public void onIOException(IOException iox, Task task) {
    _cancelButton.setEnabled(false);
    if (task != null) {
      _taskPanel.setTaskFailed(task);
    }
    JOptionPane.showMessageDialog(this, "The following communication exception occured:\n"+iox.getClass().getName()+"\n"+iox.getMessage(), "Warning", JOptionPane.WARNING_MESSAGE);
  }
  
  public void onAbortCheck() throws UserAbortIOException {
    if (_abort) {
      throw new UserAbortIOException();
    }
  }
  
  //// inner classes
  
  
  private class CancelListener implements ActionListener {
    
    public void actionPerformed(ActionEvent event) {
      _abort = true;
      _cancelButton.setEnabled(false);
    }
  }
  
  private class ExitListener implements ActionListener {
    
    public void actionPerformed(ActionEvent event) {
      System.exit(0);
    }
  }


}
