/*******************************************************************

   This software is the confidential  and proprietary information of
   NetCat AG.   You shall not disclose such confidential information
   and shall use it only in accordance with the terms of the license
   agreement you entered into with NetCat AG.

   Copyright (c) 2003 by NetCat AG, www.netcat.li

   Author: Arthur Marxer, Dipl. Informatik-Ing. ETH

*******************************************************************/

import java.io.*;
import java.text.*;
import java.util.*;
import java.util.List;
import javax.swing.*;
import javax.swing.table.*;

import li.netcat.smartsync.*;

public class TaskModel extends AbstractTableModel {
  private static ImageIcon  _doneIcon = new ImageIcon("./images/done.gif");
  private static ImageIcon  _currentIcon = new ImageIcon("./images/current.gif");
  private static ImageIcon  _failedIcon = new ImageIcon("./images/failed.gif");
  private static DecimalFormat _trafficFormat = new DecimalFormat("#,###,###,##0");
  private List   _tasks = new ArrayList();
  private List   _icons = new ArrayList();
  
  public TaskModel() {
  }
  
  //// public methods
  
  public void addTask(Task task) {
    int row = _tasks.size();
    _tasks.add(task);
    _icons.add(null);
    fireTableRowsInserted(row, row);
  }
  
  public void setCurrentTask(Task task) {
    setIcon(task, _currentIcon);
  }

  public void setTaskFailed(Task task) {
    setIcon(task, _failedIcon);
  }
  
  public void setTaskCompleted(Task task) {
    setIcon(task, _doneIcon);
  }
  
  public int getPreferredColumnWidth(int column) {
    switch (column) {
    case 0:
      return 50;
    case 1:
      return 90;
    case 2:
      return 195;
    case 3:
      return 125;
    case 4:
      return 65;
    default:
      throw new IndexOutOfBoundsException();
    }
  }
  
  //// overridden methods
  
  
  public Class getColumnClass(int column) {
    switch (column) {
    case 0:
      return ImageIcon.class;
    case 1:
      return String.class;
    case 2:
      return String.class;
    case 3:
      return String.class;
    case 4:
      return Number.class;
    default:
      throw new IndexOutOfBoundsException();
    }
  }
  
  public int getRowCount() {
    return _tasks.size();
  }
  
  public int getColumnCount() {
    return 5;
  }
  
  public String getColumnName(int column) {
    switch (column) {
    case 0:
      return "Status";
    case 1:
      return "Operation";
    case 2:
      return "File";
    case 3:
      return "Path";
    case 4:
      return "Traffic";
    default:
      throw new IndexOutOfBoundsException();
    }
  }
  
  public Object getValueAt(int row, int column) {
    if (column == 0) {
      return _icons.get(row);
    }
    else {
      Task task = (Task)_tasks.get(row);
      switch (column) {
      case 1:
        return task.getVerb();
      case 2:
        return task.getName();
      case 3:
        return task.getPath();
      case 4:
        if (task.isTransferTask()) {
          return _trafficFormat.format(task.getTransferLength());
        }
        return null;
      default:
        throw new IndexOutOfBoundsException();
      }
    }
  }
  
  
  //// private helpers
  
  private void setIcon(Task task, Icon icon) {
    int index = _tasks.indexOf(task);
    if (index >= 0) {
      _icons.set(index, icon);
      super.fireTableCellUpdated(index, 0);
    }
  }


  
}
